@@ -34,7 +34,7 @@ class ApplicationAwareResourceQuota(NamespacedResource):
 
     def to_dict(self):
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.hard:
                 raise MissingRequiredArgumentError(argument="hard")
 
